@@ -21,6 +21,7 @@ from unify.properties import ClusterSetting
 from unify.sources import Sources
 from unify.pipelines import Pipelines
 from unify.apimanager import ApiManager
+from unify.connectors import Connectors
 from unify.WaitingLibrary import Wait
 
 cluster_name = "qa"
@@ -61,4 +62,13 @@ api_manager = ApiManager(cluster=cluster_name, props=props)
 
 test_hierarchy = api_manager.create_hierarchy(name=str(uuid.uuid4()), org_id=test_org)
 
+connectors = Connectors(cluster=cluster_name, props=props)
+
+test_connector = connectors.create_connector(
+    org_id=test_org,
+    name=str(uuid.uuid4()),
+    connector_type='connector_test_type',
+    config={'a':'b'},
+)
+
 print("--------Created organization {} for testing------", format(test_org))
