@@ -220,3 +220,18 @@ class TestSourcesWithOrgID(unittest.TestCase):
             self.assertTrue(True, "Dataset was created")
         except Exception as e:
             self.assertTrue(False, e)
+
+    def test_wait_for_pipeline(self):
+        """
+        Verify waitfor dataset endpoint
+        :return:
+        """
+        try:
+            _ = self.sources.wait_for_dataset(
+                dataset_id=test_dataset["id"],
+                org_id=test_org
+            )
+
+            self.assertTrue(True, "Dataset became ready")
+        except Exception as e:
+            self.assertTrue(False, e)
