@@ -20,12 +20,14 @@ import time
 
 import json
 import requests
+from unify.helpers.graph_ql.graphql import GraphQLBuilder
 
 
 class ApiRequestManager:
     """
     Class to interact with general api request methods
     """
+    OK = [200, 201, 202]
 
     def __init__(self, cluster, props, org_id=None):
         """
@@ -42,7 +44,7 @@ class ApiRequestManager:
         self.content_octet = {"content-type": "application/octet-stream"}
         self.upload_content_type_header = {"Content-Type": "multipart/form-data"}
         self.delete_content_type_header = {"Content-Type": "application/json"}
-        self.different_content_type={"'Content-Type'": "application/json"}
+        self.different_content_type = {"'Content-Type'": "application/json"}
 
         self.list_templates_uri = 'api/assetTemplates'
 
@@ -75,6 +77,8 @@ class ApiRequestManager:
 
         self.gql_url = self.props.get_remote(self.cluster) + "artifacts/graphql"
 
+        self.upper_gql_builder = GraphQLBuilder()
+
     def close_session(self):
         """
         Closes request session
@@ -154,6 +158,39 @@ class ApiRequestManager:
 
         return query_results
 
+    def wait_for_artifact(self, org_id, artifact_id, artifact_type):
+
+        query = self.upper_gql_builder.build_wait_for_query(artifact_id=artifact_id, artifact_type=artifact_type)
+
+        get_pipelines_request = self.graph_ql_query(org_id=org_id, query=query)
+
+        if get_pipelines_request.status_code in self.OK:
+            data = json.loads(get_pipelines_request.content)
+            if "data" in data:
+                if "waitFor" in data["data"]:
+                    return data["data"]["waitFor"]
+
+            return []
+
+        raise Exception(repr(get_pipelines_request.content))
+
+    def update_artifact_metadata(self, org_id=None, *,artifact_type, artifact_id=None, name=None, description=None, facets=None):
+
+        query = self.upper_gql_builder.mutation_query(
+            artifact_id=str(artifact_id),
+            artifact_type=artifact_type,
+            new_name=name,
+            description=description,
+            facets=facets
+        )
+
+        response = self.graph_ql_query(org_id=org_id, query=query)
+
+        if response.status_code in self.OK:
+            return json.loads(response.content)
+
+        raise Exception(repr(response.content))
+
     def build_header(self, aut_token=None, org_id=None, others=None):
         """
         Creates request header
