@@ -100,6 +100,8 @@ class Pipelines(ApiRequestManager):
             self.distinct_values_url = self.props.get_remote(
                 self.cluster) + 'tags/org/{}/pipelines/{}/flows/{}/distinctValues'
 
+            self.group_components_url = self.pipeline_url + "/groupComponents"
+
             self.gql_builder = PipelineGrapql()
 
         except Exception as error:
@@ -645,6 +647,7 @@ class Pipelines(ApiRequestManager):
     def update_pipeline_metadata(self, org_id=None, *, pipeline_id=None, name=None, description=None, facets=None):
         """
         Method to update a pipeline's metadata
+
         :param org_id: org id where the pipeline is stored
         :param pipeline_id: id of the pipeline to be edited
         :param name: new pipeline name
@@ -653,20 +656,15 @@ class Pipelines(ApiRequestManager):
         :return:
         """
 
-        query = self.gql_builder.mutation_query(
-            pipeline_id=str(pipeline_id),
-            new_name=name,
+        return self.update_artifact_metadata(
+            org_id=org_id,
+            artifact_id=pipeline_id,
+            artifact_type="pipeline",
+            name=name,
             description=description,
             facets=facets
         )
 
-        response = self.graph_ql_query(org_id=org_id, query=query)
-
-        if response.status_code in [200, 201, 202]:
-            return json.loads(response.content)
-
-        raise Exception(repr(response.content))
-
     @single_org
     def preview_flow(self, org_id=None, *, pipeline_id, flow_id):
 
@@ -833,3 +831,51 @@ class Pipelines(ApiRequestManager):
             return json.loads(post_pipeline_request.content)
 
         raise Exception(repr(post_pipeline_request.content))
+
+    @single_org
+    def wait_for_pipeline(self, org_id=None, *, pipeline_id):
+        """
+        Wait for a pipeline to be ready to be used
+
+        :param org_id: Organization id where the pipeline was created
+        :param pipeline_id: pipeline id number
+        :return:
+        """
+
+        return self.wait_for_artifact(
+            org_id=org_id,
+            artifact_id=pipeline_id,
+            artifact_type="pipeline"
+        )
+
+    @single_org
+    def group_components(self, org_id=None, *, pipeline_id, components: list = None):
+        """
+        Group pipeline components
+
+        :param org_id: org id where the pipeline is stored
+        :param pipeline_id: id of the pipeline to be edited
+        :param components: list of pipeline components ids to be grouped
+        :return:
+        """
+
+        if components is None or len(components) == 0:
+            raise Exception("Component list must have at least one ID")
+
+        headers = self.build_header(
+            others=self.content_type_header,
+            org_id=str(org_id)
+        )
+
+        payload = {"componentIds": components}
+
+        post_pipeline_request = self.session.post(
+            self.group_components_url.format(org_id, pipeline_id),
+            headers=headers,
+            data=json.dumps(payload)
+        )
+
+        if post_pipeline_request.status_code in self.OK:
+            return json.loads(post_pipeline_request.content)
+
+        raise Exception(repr(post_pipeline_request.content))
