@@ -414,12 +414,6 @@ class Properties:
                 cluster = self.get_default()
 
             value = keyring.get_password(self._SYSTEM, self._AUTHTOKEN.format(cluster))
-            if value is None:
-                msg = (
-                    "Authentication is required with "
-                    "remote server, ah cluster login --remote {}".format(cluster)
-                )
-                raise Exception(msg)
 
             return value
 
